import React, { useState } from "react";
import { View, TouchableOpacity, Text, Image } from "react-native";

const Checkbox = ({
  label,
  onChange,
  source,
  checkBoxStyle,
  containerStyle,
  imageStyle,
}) => {
  const [checked, setChecked] = useState(false);

  const handleCheckboxChange = () => {
    const newChecked = !checked;
    setChecked(newChecked);

    if (onChange) {
      onChange(newChecked);
    }
  };

  return (
    <TouchableOpacity
      style={[
        {
          flexDirection: "row",
          alignItems: "center",
          marginVertical: 5,
          marginHorizontal: 10,
        },
        containerStyle,
      ]}
      onPress={handleCheckboxChange}
    >
      <View
        style={[
          {
            height: 21,
            width: 22,
            borderRadius: 4,
            borderWidth: 2,
            borderColor: checked ? "#000000" : "#AAAAAA",
            alignItems: "center",
            justifyContent: "center",
          },
          checkBoxStyle,
        ]}
      >
        {checked && (
          <Image
            style={[
              {
                height: 12,
                width: 12,
              },
              imageStyle,
            ]}
            source={source}
          />
        )}
      </View>
      <Text style={{ marginLeft: 8 }}>{label}</Text>
    </TouchableOpacity>
  );
};

const CheckBox = ({
  length,
  source,
  checkBoxStyle,
  containerStyle,
  lable,
  options = [],
  imageStyle,
}) => {
  const handleCheckboxChange = (checked) => {
    console.log("Checkbox checked:", checked);
  };

  const renderCheckboxes = () => {
    const checkboxes = [];
    for (let i = 0; i < length; i++) {
      checkboxes.push(
        <Checkbox
          key={`checkbox-${i}`}
          label={options[i]}
          onChange={handleCheckboxChange}
          source={source}
          checkBoxStyle={checkBoxStyle}
          containerStyle={containerStyle}
          label1={lable}
          imageStyle={imageStyle}
        />
      );
    }
    return checkboxes;
  };

  return <View>{renderCheckboxes()}</View>;
};

export default CheckBox;
